@@ -1,3 +1,23 @@
+setMethod(f="initialize",
+          signature="windrose",
+          definition=function(.Object) {
+              .Object@processingLog$time=c(.Object@processingLog$time, Sys.time())
+              .Object@processingLog$value=c(.Object@processingLog$value, "create 'windrose' object")
+              return(.Object)
+          })
+
+setMethod(f="[[",
+          signature="windrose",
+          definition=function(x, i, j, drop) {
+              ## 'j' can be for times, as in OCE
+              ##if (!missing(j)) cat("j=", j, "*****\n")
+              i <- match.arg(i, c("theta", "count", "fives"))
+              if (i == "theta") return(x@data$theta)
+              else if (i == "count") return(x@data$count)
+              else if (i == "fives") return(x@data$fives)
+              else stop("cannot access \"", i, "\"") # cannot get here
+          })
+
 as.windrose <- function(x, y, dtheta = 15)
 {
     dt <- dtheta * pi / 180
@@ -19,12 +39,11 @@ as.windrose <- function(x, y, dtheta = 15)
         mean[i] <- mean(R[inside], na.rm=TRUE)
         fives[i,] <- fivenum(R[inside])
     }
-    data <- list(n=length(x), x.mean=mean(x, na.rm=TRUE), y.mean=mean(y, na.rm=TRUE), theta=theta*180/pi,
-                 count=count, mean=mean, fives=fives)
-    metadata <- list(dtheta=dtheta)
-    log <- processingLogItem(paste(deparse(match.call()), sep="", collapse=""))
-    res <- list(data=data, metadata=metadata, processingLog=log)
-    class(res) <- c("windrose", "oce")
+    res <- new('windrose')
+    res@data <- list(n=length(x), x.mean=mean(x, na.rm=TRUE), y.mean=mean(y, na.rm=TRUE), theta=theta*180/pi,
+                     count=count, mean=mean, fives=fives)
+    res@metadata <- list(dtheta=dtheta)
+    res@processingLog <- processingLog(res@processingLog, paste(deparse(match.call()), sep="", collapse=""))
     res
 }
 
@@ -38,8 +57,8 @@ plot.windrose <- function(x,
     if (!inherits(x, "windrose"))
         stop("method is only for wind-rose objects")
     type <- match.arg(type)
-    nt <- length(x$data$theta)
-    t <- x$data$theta * pi / 180        # in radians
+    nt <- length(x@data$theta)
+    t <- x@data$theta * pi / 180        # in radians
     dt <- t[2] - t[1]
     dt2 <- dt / 2
                                         # Plot setup
@@ -71,9 +90,9 @@ plot.windrose <- function(x,
     text( 1,  0, "E", pos=4)
                                         # Draw rose in a given type
     if (type == "count") {
-        max <- max(x$data$count, na.rm=TRUE)
+        max <- max(x@data$count, na.rm=TRUE)
         for (i in 1:nt) {
-            r <- x$data$count[i] / max
+            r <- x@data$count[i] / max
             ##cat("t=", t[i], " r=", r, "\n")
             xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
             ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
@@ -81,9 +100,9 @@ plot.windrose <- function(x,
         }
         title(paste("Counts (max ", max, ")", sep=""))
     } else if (type == "mean") {
-        max <- max(x$data$mean, na.rm=TRUE)
+        max <- max(x@data$mean, na.rm=TRUE)
         for (i in 1:nt) {
-            r <- x$data$mean[i] / max
+            r <- x@data$mean[i] / max
             ##cat("t=", t[i], " r=", r, "\n")
             xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
             ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
@@ -91,9 +110,9 @@ plot.windrose <- function(x,
         }
         title(paste("Means (max ", sprintf(max, fmt="%.3g"), ")", sep=""))
     } else if (type == "median") {
-        max <- max(x$data$fives[,5], na.rm=TRUE)
+        max <- max(x@data$fives[,5], na.rm=TRUE)
         for (i in 1:nt) {
-            r <- x$data$fives[i,3] / max
+            r <- x@data$fives[i,3] / max
             ##cat("t=", t[i], " r=", r, "\n")
             xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
             ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
@@ -101,19 +120,19 @@ plot.windrose <- function(x,
         }
         title(paste("Medians (max ", sprintf(max,fmt="%.3g"), ")", sep=""))
     } else if (type == "fivenum") {
-        max <- max(x$data$fives[,3], na.rm=TRUE)
+        max <- max(x@data$fives[,3], na.rm=TRUE)
         for (i in 1:nt) {
             for (j in 2:3) {
                 tm <- t[i] - dt2
                 tp <- t[i] + dt2
-                r0 <- x$data$fives[i, j-1] / max
-                r  <- x$data$fives[i, j  ] / max
+                r0 <- x@data$fives[i, j-1] / max
+                r  <- x@data$fives[i, j  ] / max
                 xlist <- c(r0 * cos(tm), r * cos(tm), r * cos(tp), r0 * cos(tp))
                 ylist <- c(r0 * sin(tm), r * sin(tm), r * sin(tp), r0 * sin(tp))
                 thiscol <- col[c(2,1,1,2)][j-1]
                 polygon(xlist, ylist, col=thiscol, border=col[4])
             }
-            r <- x$data$fivenum[i, 3] / max
+            r <- x@data$fivenum[i, 3] / max
             lines(c(r * cos(tm), r * cos(tp)), c(r * sin(tm), r * sin(tp)), col="blue", lwd=2)
         }
         title(paste("Fiveum (max ", sprintf(max,fmt="%.3g"), ")", sep=""))
@@ -125,28 +144,18 @@ summary.windrose <- function(object, ...)
 {
     if (!inherits(object, "windrose"))
         stop("method is only for windrose objects")
-    n <- length(object$data$theta)
-    threes <- matrix(nrow=n, ncol=3)
-    res <- list(n=n,
-                dtheta=object$metadata$dtheta,
-                threes=threes,
-                processingLog=object$processingLog)
-    for (i in 1:n) {
-        threes[i,] <- c(object$data$fivenum[i,1], object$data$mean[i], object$data$fivenum[i, 5])
-    }
-    colnames(threes) <- c("Min.", "Mean", "Max.")
-    rownames(threes) <- object$data$theta
-    res$threes <- threes
-    class(res) <- "summary.windrose"
-    res
+    cat("Windrose data\n-------------\n\n")
+    n <- length(object@data$theta)
+    dtheta <- abs(diff(object@data$theta[1:2]))
+    cat("* Have n=", n, "angles, separated by dtheta=", dtheta,"\n\n")
+    ##cat("* Statistics by angle::\n\n", ...)
+    ##threes <- matrix(nrow=2, ncol=3)
+    ##threes[1,] <- threenum(object@data$theta)
+    ##threes[2,] <- threenum(object@data$count)
+    ##colnames(threes) <- c("Min.", "Mean", "Max.")
+    ##rownames(threes) <- c("theta", "count")
+    ##print(threes)
+    ##cat('\n')
+    processingLogShow(object)
 }
 
-print.summary.windrose <- function(x, digits=max(6, getOption("digits") - 1), ...)
-{
-    cat("Windrose data\n-------------\n\n")
-    cat("* Have n=", x$n, "angles, separated by dtheta=", x$dtheta,"\n\n")
-    cat("* Statistics by angle::\n\n", ...)
-    cat(showThrees(x, indent='     '), ...)
-    print(summary(x$processingLog))
-    invisible(x)
-}
